ClusterTransformer

Trait ClusterTransformer 

pub trait ClusterTransformer: NameTransformer {
    // Required methods
    fn transform_cluster(&self, cluster_name: &Ident) -> Ident;
    fn get_original_cluster_name(&self, staged_name: &str) -> String;
}
Extension trait for transformers that also transform cluster names.

This trait allows transformers to modify cluster references in addition to object names. It’s used by the StagingTransformer to rename clusters for staging environments.

Required Methods

fn transform_cluster(&self, cluster_name: &Ident) -> Ident

Transform a cluster name according to the strategy.

fn get_original_cluster_name(&self, staged_name: &str) -> String

Get the original cluster name from a transformed name.

This is used to look up production cluster configurations when creating staging clusters.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors